// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_net_NoRouteToHostException__
#define __java_net_NoRouteToHostException__

#pragma interface

#include <java/net/SocketException.h>

extern "Java"
{
  namespace java
  {
    namespace net
    {
      class NoRouteToHostException;
    }
  }
};

class ::java::net::NoRouteToHostException : public ::java::net::SocketException
{
public:
  NoRouteToHostException ();
  NoRouteToHostException (::java::lang::String *);

  static ::java::lang::Class class$;
};

#endif /* __java_net_NoRouteToHostException__ */
