// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_w3c_dom_Node__
#define __org_w3c_dom_Node__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace w3c
    {
      namespace dom
      {
        class Document;
        class NamedNodeMap;
        class NodeList;
        class Node;
      }
    }
  }
};

class ::org::w3c::dom::Node : public ::java::lang::Object
{
public:
  virtual ::java::lang::String *getNodeName () = 0;
  virtual ::java::lang::String *getNodeValue () = 0;
  virtual void setNodeValue (::java::lang::String *) = 0;
  virtual jshort getNodeType () = 0;
  virtual ::org::w3c::dom::Node *getParentNode () = 0;
  virtual ::org::w3c::dom::NodeList *getChildNodes () = 0;
  virtual ::org::w3c::dom::Node *getFirstChild () = 0;
  virtual ::org::w3c::dom::Node *getLastChild () = 0;
  virtual ::org::w3c::dom::Node *getPreviousSibling () = 0;
  virtual ::org::w3c::dom::Node *getNextSibling () = 0;
  virtual ::org::w3c::dom::NamedNodeMap *getAttributes () = 0;
  virtual ::org::w3c::dom::Document *getOwnerDocument () = 0;
  virtual ::org::w3c::dom::Node *insertBefore (::org::w3c::dom::Node *, ::org::w3c::dom::Node *) = 0;
  virtual ::org::w3c::dom::Node *replaceChild (::org::w3c::dom::Node *, ::org::w3c::dom::Node *) = 0;
  virtual ::org::w3c::dom::Node *removeChild (::org::w3c::dom::Node *) = 0;
  virtual ::org::w3c::dom::Node *appendChild (::org::w3c::dom::Node *) = 0;
  virtual jboolean hasChildNodes () = 0;
  virtual ::org::w3c::dom::Node *cloneNode (jboolean) = 0;
  virtual void normalize () = 0;
  virtual jboolean isSupported (::java::lang::String *, ::java::lang::String *) = 0;
  virtual ::java::lang::String *getNamespaceURI () = 0;
  virtual ::java::lang::String *getPrefix () = 0;
  virtual void setPrefix (::java::lang::String *) = 0;
  virtual ::java::lang::String *getLocalName () = 0;
  virtual jboolean hasAttributes () = 0;
  static const jint ELEMENT_NODE = 1L;
  static const jint ATTRIBUTE_NODE = 2L;
  static const jint TEXT_NODE = 3L;
  static const jint CDATA_SECTION_NODE = 4L;
  static const jint ENTITY_REFERENCE_NODE = 5L;
  static const jint ENTITY_NODE = 6L;
  static const jint PROCESSING_INSTRUCTION_NODE = 7L;
  static const jint COMMENT_NODE = 8L;
  static const jint DOCUMENT_NODE = 9L;
  static const jint DOCUMENT_TYPE_NODE = 10L;
  static const jint DOCUMENT_FRAGMENT_NODE = 11L;
  static const jint NOTATION_NODE = 12L;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __org_w3c_dom_Node__ */
