// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_applet_Applet__
#define __java_applet_Applet__

#pragma interface

#include <java/awt/Panel.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Image;
      class Dimension;
    }
    namespace net
    {
      class URL;
    }
    namespace applet
    {
      class Applet;
      class AudioClip;
      class AppletContext;
      class AppletStub;
    }
  }
};

class ::java::applet::Applet : public ::java::awt::Panel
{
public:
  Applet ();
  virtual ::java::net::URL *getDocumentBase ();
  virtual ::java::net::URL *getCodeBase ();
  virtual ::java::lang::String *getParameter (::java::lang::String *);
  virtual ::java::applet::AppletContext *getAppletContext ();
  virtual jboolean isActive ();
  virtual void resize (jint, jint);
  virtual void resize (::java::awt::Dimension *);
  virtual ::java::applet::AudioClip *getAudioClip (::java::net::URL *);
  virtual ::java::applet::AudioClip *getAudioClip (::java::net::URL *, ::java::lang::String *);
  virtual void play (::java::net::URL *);
  virtual void play (::java::net::URL *, ::java::lang::String *);
  virtual ::java::awt::Image *getImage (::java::net::URL *);
  virtual ::java::awt::Image *getImage (::java::net::URL *, ::java::lang::String *);
  virtual ::java::util::Locale *getLocale ();
  virtual ::java::lang::String *getAppletInfo () { return 0; }
  virtual JArray<JArray< ::java::lang::String *> *> *getParameterInfo () { return 0; }
  virtual void init () { }
  virtual void destroy () { }
  virtual void start () { }
  virtual void stop () { }
  void setStub (::java::applet::AppletStub *);
private:
  ::java::applet::AppletStub *stub;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_applet_Applet__ */
