// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_gcj_runtime_SharedLibLoader__
#define __gnu_gcj_runtime_SharedLibLoader__

#pragma interface

#include <java/lang/ClassLoader.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace gcj
    {
      namespace runtime
      {
        class SharedLibLoader;
      }
      class RawData;
    }
  }
};

class ::gnu::gcj::runtime::SharedLibLoader : public ::java::lang::ClassLoader
{
public:
  virtual void finalize ();
public: // actually package-private
  virtual void registerClass (::java::lang::String *, ::java::lang::Class *);
public:
  SharedLibLoader (::java::lang::String *, ::java::lang::ClassLoader *, jint);
  SharedLibLoader (::java::lang::String *);
public: // actually package-private
  virtual void init (::java::lang::String *, jint);
  virtual void init (jbyteArray, jint);
public:
  virtual ::java::lang::Class *loadClass (::java::lang::String *);
  virtual ::java::lang::Class *findClass (::java::lang::String *);
public: // actually package-private
  ::gnu::gcj::RawData *handler;
  ::java::util::Hashtable *classMap;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_gcj_runtime_SharedLibLoader__ */
