// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_BasicMapEntry__
#define __java_util_BasicMapEntry__

#pragma interface

#include <java/lang/Object.h>

class ::java::util::BasicMapEntry : public ::java::lang::Object
{
public: // actually package-private
  BasicMapEntry (::java::lang::Object *, ::java::lang::Object *);
public:
  jboolean equals (::java::lang::Object *);
  ::java::lang::Object *getKey () { return key; }
  ::java::lang::Object *getValue () { return value; }
  jint hashCode ();
  virtual ::java::lang::Object *setValue (::java::lang::Object *);
  ::java::lang::String *toString ();
public: // actually package-private
  ::java::lang::Object *key;
  ::java::lang::Object *value;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_util_BasicMapEntry__ */
