// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_io_FileOutputStream__
#define __java_io_FileOutputStream__

#pragma interface

#include <java/io/OutputStream.h>
#include <gcj/array.h>

class ::java::io::FileOutputStream : public ::java::io::OutputStream
{
public:
  FileOutputStream (::java::lang::String *, jboolean);
  FileOutputStream (::java::lang::String *);
  FileOutputStream (::java::io::File *);
  FileOutputStream (::java::io::FileDescriptor *);
public:  // actually protected
  virtual void finalize () { }
public:
  ::java::io::FileDescriptor *getFD ();
  virtual void write (jint);
  virtual void write (jbyteArray);
  virtual void write (jbyteArray, jint, jint);
  virtual void close ();
private:
  ::java::io::FileDescriptor *fd;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_io_FileOutputStream__ */
