// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_security_PrivilegedActionException__
#define __java_security_PrivilegedActionException__

#pragma interface

#include <java/lang/Exception.h>

extern "Java"
{
  namespace java
  {
    namespace security
    {
      class PrivilegedActionException;
    }
  }
};

class ::java::security::PrivilegedActionException : public ::java::lang::Exception
{
public:
  PrivilegedActionException (::java::lang::Exception *);
  virtual ::java::lang::Exception *getException () { return e; }
  virtual void printStackTrace ();
  virtual void printStackTrace (::java::io::PrintStream *);
  virtual void printStackTrace (::java::io::PrintWriter *);
private:
  ::java::lang::Exception *e;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_security_PrivilegedActionException__ */
