// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_rmi_activation_ActivationID__
#define __java_rmi_activation_ActivationID__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace rmi
    {
      class Remote;
      namespace activation
      {
        class ActivationID;
        class Activator;
      }
    }
  }
};

class ::java::rmi::activation::ActivationID : public ::java::lang::Object
{
public:
  ActivationID (::java::rmi::activation::Activator *);
  virtual ::java::rmi::Remote *activate (jboolean);
  virtual jint hashCode ();
  virtual jboolean equals (::java::lang::Object *);
private:
  ::java::rmi::activation::Activator *activator;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_rmi_activation_ActivationID__ */
