( cd usr/lib ; rm -rf libgcj.so )
( cd usr/lib ; ln -sf libgcj.so.3.0.0 libgcj.so )
( cd usr/lib ; rm -rf libgcj.so.3 )
( cd usr/lib ; ln -sf libgcj.so.3.0.0 libgcj.so.3 )
# Install the info files for this package
if [ -x usr/bin/install-info ]
then
   usr/bin/install-info --info-dir=/usr/info /usr/info/gcj.info.gz 2>/dev/null
fi

