// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_ClassFormatError__
#define __java_lang_ClassFormatError__

#pragma interface

#include <java/lang/LinkageError.h>

class ::java::lang::ClassFormatError : public ::java::lang::LinkageError
{
public:
  ClassFormatError ();
  ClassFormatError (::java::lang::String *);
public: // actually package-private
  static const jlong serialVersionUID = -8420114879011949195LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_ClassFormatError__ */
