// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_event_WindowEvent__
#define __java_awt_event_WindowEvent__

#pragma interface

#include <java/awt/event/ComponentEvent.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace event
      {
        class WindowEvent;
      }
      class Window;
    }
  }
};

class ::java::awt::event::WindowEvent : public ::java::awt::event::ComponentEvent
{
public:
  WindowEvent (::java::awt::Window *, jint);
  virtual ::java::awt::Window *getWindow ();
  virtual ::java::lang::String *paramString ();
  static const jint WINDOW_ACTIVATED = 205L;
  static const jint WINDOW_CLOSED = 202L;
  static const jint WINDOW_CLOSING = 201L;
  static const jint WINDOW_DEACTIVATED = 206L;
  static const jint WINDOW_DEICONIFIED = 204L;
  static const jint WINDOW_FIRST = 200L;
  static const jint WINDOW_ICONIFIED = 203L;
  static const jint WINDOW_LAST = 206L;
  static const jint WINDOW_OPENED = 200L;

  static ::java::lang::Class class$;
};

#endif /* __java_awt_event_WindowEvent__ */
