// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_zip_ZipEntry__
#define __java_util_zip_ZipEntry__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

class ::java::util::zip::ZipEntry : public ::java::lang::Object
{
public:
  ZipEntry (::java::lang::String *);
  ZipEntry (::java::util::zip::ZipEntry *);
  virtual ::java::lang::Object *clone ();
  virtual ::java::lang::String *getComment () { return comment; }
  virtual jlong getCompressedSize () { return compressedSize; }
  virtual jlong getCrc () { return crc; }
  virtual jbyteArray getExtra () { return extra; }
  virtual jint getMethod () { return method; }
  virtual ::java::lang::String *getName () { return name; }
  virtual jlong getSize () { return size; }
  virtual jlong getTime () { return time; }
  virtual jboolean isDirectory ();
  virtual void setComment (::java::lang::String *);
  virtual void setCompressedSize (jlong);
  virtual void setCrc (jlong);
  virtual void setExtra (jbyteArray);
  virtual void setMethod (jint);
  virtual void setSize (jlong);
  virtual void setTime (jlong);
public: // actually package-private
  static jlong timeFromDOS (jint, jint);
public:
  virtual ::java::lang::String *toString () { return name; }
  virtual jint hashCode ();
  static const jint STORED = 0L;
  static const jint DEFLATED = 8L;
public: // actually package-private
  ::java::lang::String *comment;
  jlong compressedSize;
  jlong crc;
  jbyteArray extra;
  jint method;
  ::java::lang::String *name;
  jlong size;
  jlong time;
  jlong relativeOffset;
  ::java::util::zip::ZipEntry *next;
private:
  static jshortArray daysToMonthStart;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_util_zip_ZipEntry__ */
