// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_xml_sax_helpers_AttributesImpl__
#define __org_xml_sax_helpers_AttributesImpl__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace xml
    {
      namespace sax
      {
        namespace helpers
        {
          class AttributesImpl;
        }
        class Attributes;
      }
    }
  }
};

class ::org::xml::sax::helpers::AttributesImpl : public ::java::lang::Object
{
public:
  AttributesImpl ();
  AttributesImpl (::org::xml::sax::Attributes *);
  virtual jint getLength () { return length; }
  virtual ::java::lang::String *getURI (jint);
  virtual ::java::lang::String *getLocalName (jint);
  virtual ::java::lang::String *getQName (jint);
  virtual ::java::lang::String *getType (jint);
  virtual ::java::lang::String *getValue (jint);
  virtual jint getIndex (::java::lang::String *, ::java::lang::String *);
  virtual jint getIndex (::java::lang::String *);
  virtual ::java::lang::String *getType (::java::lang::String *, ::java::lang::String *);
  virtual ::java::lang::String *getType (::java::lang::String *);
  virtual ::java::lang::String *getValue (::java::lang::String *, ::java::lang::String *);
  virtual ::java::lang::String *getValue (::java::lang::String *);
  virtual void clear ();
  virtual void setAttributes (::org::xml::sax::Attributes *);
  virtual void addAttribute (::java::lang::String *, ::java::lang::String *, ::java::lang::String *, ::java::lang::String *, ::java::lang::String *);
  virtual void setAttribute (jint, ::java::lang::String *, ::java::lang::String *, ::java::lang::String *, ::java::lang::String *, ::java::lang::String *);
  virtual void removeAttribute (jint);
  virtual void setURI (jint, ::java::lang::String *);
  virtual void setLocalName (jint, ::java::lang::String *);
  virtual void setQName (jint, ::java::lang::String *);
  virtual void setType (jint, ::java::lang::String *);
  virtual void setValue (jint, ::java::lang::String *);
private:
  void ensureCapacity (jint);
  void badIndex (jint);
public: // actually package-private
  jint length;
  JArray< ::java::lang::String *> *data;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_xml_sax_helpers_AttributesImpl__ */
