// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_sql_SQLData__
#define __java_sql_SQLData__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace sql
    {
      class SQLData;
      class SQLOutput;
      class SQLInput;
    }
  }
};

class ::java::sql::SQLData : public ::java::lang::Object
{
public:
  virtual ::java::lang::String *getSQLTypeName () = 0;
  virtual void readSQL (::java::sql::SQLInput *, ::java::lang::String *) = 0;
  virtual void writeSQL (::java::sql::SQLOutput *) = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __java_sql_SQLData__ */
