// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_rmi_NoSuchObjectException__
#define __java_rmi_NoSuchObjectException__

#pragma interface

#include <java/rmi/RemoteException.h>

extern "Java"
{
  namespace java
  {
    namespace rmi
    {
      class NoSuchObjectException;
    }
  }
};

class ::java::rmi::NoSuchObjectException : public ::java::rmi::RemoteException
{
public:
  NoSuchObjectException (::java::lang::String *);
  static const jlong serialVersionUID = 6619395951570472985LL;

  static ::java::lang::Class class$;
};

#endif /* __java_rmi_NoSuchObjectException__ */
