// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_security_DummyMessageDigest__
#define __java_security_DummyMessageDigest__

#pragma interface

#include <java/security/MessageDigest.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace security
    {
      class DummyMessageDigest;
      class MessageDigestSpi;
    }
  }
};

class ::java::security::DummyMessageDigest : public ::java::security::MessageDigest
{
public:
  DummyMessageDigest (::java::security::MessageDigestSpi *, ::java::lang::String *);
public:  // actually protected
  void engineUpdate (jbyte);
  void engineUpdate (jbyteArray, jint, jint);
  jbyteArray engineDigest ();
  void engineReset ();
private:
  ::java::security::MessageDigestSpi *mdSpi;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_security_DummyMessageDigest__ */
