// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_xml_sax_helpers_AttributeListImpl__
#define __org_xml_sax_helpers_AttributeListImpl__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace xml
    {
      namespace sax
      {
        namespace helpers
        {
          class AttributeListImpl;
        }
        class AttributeList;
      }
    }
  }
};

class ::org::xml::sax::helpers::AttributeListImpl : public ::java::lang::Object
{
public:
  AttributeListImpl ();
  AttributeListImpl (::org::xml::sax::AttributeList *);
  virtual void setAttributeList (::org::xml::sax::AttributeList *);
  virtual void addAttribute (::java::lang::String *, ::java::lang::String *, ::java::lang::String *);
  virtual void removeAttribute (::java::lang::String *);
  virtual void clear ();
  virtual jint getLength ();
  virtual ::java::lang::String *getName (jint);
  virtual ::java::lang::String *getType (jint);
  virtual ::java::lang::String *getValue (jint);
  virtual ::java::lang::String *getType (::java::lang::String *);
  virtual ::java::lang::String *getValue (::java::lang::String *);
public: // actually package-private
  ::java::util::Vector *names;
  ::java::util::Vector *types;
  ::java::util::Vector *values;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_xml_sax_helpers_AttributeListImpl__ */
