// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_StackOverflowError__
#define __java_lang_StackOverflowError__

#pragma interface

#include <java/lang/VirtualMachineError.h>

class ::java::lang::StackOverflowError : public ::java::lang::VirtualMachineError
{
public:
  StackOverflowError ();
  StackOverflowError (::java::lang::String *);
public: // actually package-private
  static const jlong serialVersionUID = 8609175038441759607LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_StackOverflowError__ */
