// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_naming_CompoundName__
#define __javax_naming_CompoundName__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace naming
    {
      class CompoundName;
      class Name;
    }
  }
};

class ::javax::naming::CompoundName : public ::java::lang::Object
{
private:
  CompoundName (::java::util::Properties *);
public:  // actually protected
  CompoundName (::java::util::Enumeration *, ::java::util::Properties *);
public:
  CompoundName (::java::lang::String *, ::java::util::Properties *);
  virtual ::javax::naming::Name *add (jint, ::java::lang::String *);
  virtual ::javax::naming::Name *add (::java::lang::String *);
  virtual ::javax::naming::Name *addAll (jint, ::javax::naming::Name *);
  virtual ::javax::naming::Name *addAll (::javax::naming::Name *);
  virtual ::java::lang::Object *clone ();
  virtual jint compareTo (::java::lang::Object *);
  virtual jboolean endsWith (::javax::naming::Name *);
  virtual jboolean equals (::java::lang::Object *);
  virtual ::java::lang::String *get (jint);
  virtual ::java::util::Enumeration *getAll ();
  virtual ::javax::naming::Name *getPrefix (jint);
  virtual ::javax::naming::Name *getSuffix (jint);
  virtual jint hashCode ();
  virtual jboolean isEmpty ();
  virtual ::java::lang::Object *remove (jint);
  virtual jint size ();
  virtual jboolean startsWith (::javax::naming::Name *);
private:
  ::java::lang::String *isSpecial (::java::lang::String *, jint);
public:
  virtual ::java::lang::String *toString ();
private:
  ::java::lang::String *canonicalize (::java::lang::String *);
  void initializeSyntax ();
public:  // actually protected
  ::java::util::Properties *mySyntax;
private:
  ::java::util::Vector *elts;
  jint direction;
  ::java::lang::String *separator;
  jboolean ignoreCase;
  ::java::lang::String *escape;
  ::java::lang::String *beginQuote;
  ::java::lang::String *endQuote;
  ::java::lang::String *beginQuote2;
  ::java::lang::String *endQuote2;
  jboolean trimBlanks;
  static const jint RIGHT_TO_LEFT = -1L;
  static const jint LEFT_TO_RIGHT = 1L;
  static const jint FLAT = 0L;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_naming_CompoundName__ */
