// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_lang_CharData__
#define __gnu_java_lang_CharData__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace lang
      {
        class CharData;
      }
    }
  }
};

class ::gnu::java::lang::CharData : public ::java::lang::Object
{
public:
  static ::java::lang::String *SOURCE;
  static const jint SHIFT = 5L;
  static ::java::lang::String *BLOCKS;
  static ::java::lang::String *DATA;
  static ::java::lang::String *NUM_VALUE;
  static ::java::lang::String *UPPER;
  static ::java::lang::String *LOWER;
  static ::java::lang::String *DIRECTION;
  static ::java::lang::String *TITLE;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __gnu_java_lang_CharData__ */
