// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_gcj_protocol_jar_Handler__
#define __gnu_gcj_protocol_jar_Handler__

#pragma interface

#include <java/net/URLStreamHandler.h>

extern "Java"
{
  namespace gnu
  {
    namespace gcj
    {
      namespace protocol
      {
        namespace jar
        {
          class Handler;
        }
      }
    }
  }
  namespace java
  {
    namespace net
    {
      class URLConnection;
      class URL;
    }
  }
};

class ::gnu::gcj::protocol::jar::Handler : public ::java::net::URLStreamHandler
{
public:  // actually protected
  virtual ::java::net::URLConnection *openConnection (::java::net::URL *);
public:
  Handler ();

  static ::java::lang::Class class$;
};

#endif /* __gnu_gcj_protocol_jar_Handler__ */
