// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_ClassNotFoundException__
#define __java_lang_ClassNotFoundException__

#pragma interface

#include <java/lang/Exception.h>

class ::java::lang::ClassNotFoundException : public ::java::lang::Exception
{
public:
  ClassNotFoundException ();
  ClassNotFoundException (::java::lang::String *);
  ClassNotFoundException (::java::lang::String *, ::java::lang::Throwable *);
  virtual ::java::lang::Throwable *getException () { return ex; }
  virtual void printStackTrace ();
  virtual void printStackTrace (::java::io::PrintStream *);
  virtual void printStackTrace (::java::io::PrintWriter *);
private:
  void writeObject (::java::io::ObjectOutputStream *);
  void readObject (::java::io::ObjectInputStream *);
public: // actually package-private
  static const jlong serialVersionUID = 9176873029745254542LL;
private:
  ::java::lang::Throwable *ex;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_ClassNotFoundException__ */
