// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_zip_GZIPInputStream__
#define __java_util_zip_GZIPInputStream__

#pragma interface

#include <java/util/zip/InflaterInputStream.h>
#include <gcj/array.h>

class ::java::util::zip::GZIPInputStream : public ::java::util::zip::InflaterInputStream
{
public:
  virtual void close ();
  GZIPInputStream (::java::io::InputStream *);
private:
  jint eof_read ();
public:
  GZIPInputStream (::java::io::InputStream *, jint);
  virtual jint read (jbyteArray, jint, jint);
private:
  jint read4 ();
public:
  static const jint GZIP_MAGIC = 35615L;
public:  // actually protected
  ::java::util::zip::CRC32 *crc;
  jboolean eos;
public: // actually package-private
  static const jint Z_DEFLATED = 8L;
  static const jint HEAD_CRC = 2L;
  static const jint EXTRA_FIELD = 4L;
  static const jint ORIG_NAME = 8L;
  static const jint COMMENT = 16L;
  static const jint RESERVED = 224L;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_util_zip_GZIPInputStream__ */
