// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_beans_info_ComponentBeanInfo__
#define __gnu_java_beans_info_ComponentBeanInfo__

#pragma interface

#include <java/beans/SimpleBeanInfo.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace beans
      {
        namespace info
        {
          class ComponentBeanInfo;
        }
      }
    }
  }
  namespace java
  {
    namespace beans
    {
      class PropertyDescriptor;
    }
  }
};

class ::gnu::java::beans::info::ComponentBeanInfo : public ::java::beans::SimpleBeanInfo
{
public:
  ComponentBeanInfo ();
  virtual JArray< ::java::beans::PropertyDescriptor *> *getPropertyDescriptors ();
public: // actually package-private
  static JArray< ::java::beans::PropertyDescriptor *> *properties;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_beans_info_ComponentBeanInfo__ */
