// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_Runtime__
#define __java_lang_Runtime__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

class ::java::lang::Runtime : public ::java::lang::Object
{
public:
  virtual ::java::lang::Process *exec (::java::lang::String *);
  virtual ::java::lang::Process *exec (::java::lang::String *, JArray< ::java::lang::String *> *);
  virtual ::java::lang::Process *exec (JArray< ::java::lang::String *> *);
  virtual ::java::lang::Process *exec (JArray< ::java::lang::String *> *, JArray< ::java::lang::String *> *);
private:
  static void checkExit (jint);
public:
  virtual void exit (jint);
public: // actually package-private
  void _exit (jint);
public:
  virtual jlong freeMemory ();
  virtual void gc ();
  virtual ::java::io::InputStream *getLocalizedInputStream (::java::io::InputStream *);
  virtual ::java::io::OutputStream *getLocalizedOutputStream (::java::io::OutputStream *);
  static ::java::lang::Runtime *getRuntime ();
private:
  void checkLink (::java::lang::String *);
  void _load (::java::lang::String *, jboolean);
public:
  virtual void load (::java::lang::String *);
  virtual void loadLibrary (::java::lang::String *);
public: // actually package-private
  virtual jboolean loadLibraryInternal (::java::lang::String *);
public:
  virtual void runFinalization ();
  static void runFinalizersOnExit (jboolean);
  virtual jlong totalMemory ();
  virtual void traceInstructions (jboolean);
  virtual void traceMethodCalls (jboolean);
private:
  void init ();
  Runtime ();
  static ::java::lang::Runtime *self;
  jboolean finalize_on_exit;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_Runtime__ */
