// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_security_UnresolvedPermission__
#define __java_security_UnresolvedPermission__

#pragma interface

#include <java/security/Permission.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace security
    {
      class UnresolvedPermission;
      class PermissionCollection;
      class Permission;
      namespace cert
      {
        class Certificate;
      }
    }
  }
};

class ::java::security::UnresolvedPermission : public ::java::security::Permission
{
public:
  UnresolvedPermission (::java::lang::String *, ::java::lang::String *, ::java::lang::String *, JArray< ::java::security::cert::Certificate *> *);
  ::java::lang::String *getActions () { return actions; }
  jboolean implies (::java::security::Permission *);
  jboolean equals (::java::lang::Object *);
  jint hashCode ();
  ::java::lang::String *toString ();
  ::java::security::PermissionCollection *newPermissionCollection () { return 0; }
private:
  ::java::lang::String *actions;
  JArray< ::java::security::cert::Certificate *> *certs;
  ::java::lang::String *type;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_security_UnresolvedPermission__ */
