// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_net_Socket__
#define __java_net_Socket__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace net
    {
      class Socket;
      class InetAddress;
      class SocketImpl;
      class SocketImplFactory;
    }
  }
};

class ::java::net::Socket : public ::java::lang::Object
{
public:  // actually protected
  Socket ();
  Socket (::java::net::SocketImpl *);
public:
  Socket (::java::lang::String *, jint);
  Socket (::java::net::InetAddress *, jint);
  Socket (::java::lang::String *, jint, ::java::net::InetAddress *, jint);
  Socket (::java::net::InetAddress *, jint, ::java::net::InetAddress *, jint);
  Socket (::java::lang::String *, jint, jboolean);
  Socket (::java::net::InetAddress *, jint, jboolean);
private:
  Socket (::java::net::InetAddress *, jint, ::java::net::InetAddress *, jint, jboolean);
public:
  virtual ::java::net::InetAddress *getInetAddress ();
  virtual ::java::net::InetAddress *getLocalAddress ();
  virtual jint getPort ();
  virtual jint getLocalPort ();
  virtual ::java::io::InputStream *getInputStream ();
  virtual ::java::io::OutputStream *getOutputStream ();
  virtual void setTcpNoDelay (jboolean);
  virtual jboolean getTcpNoDelay ();
  virtual void setSoLinger (jboolean, jint);
  virtual jint getSoLinger ();
  virtual void setSoTimeout (jint);
  virtual jint getSoTimeout ();
  virtual void setSendBufferSize (jint);
  virtual jint getSendBufferSize ();
  virtual void setReceiveBufferSize (jint);
  virtual jint getReceiveBufferSize ();
  virtual void close ();
  virtual ::java::lang::String *toString ();
  static void setSocketImplFactory (::java::net::SocketImplFactory *);
public: // actually package-private
  static ::java::net::SocketImplFactory *factory;
  ::java::net::SocketImpl *impl;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_net_Socket__ */
