// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_net_SocketPermission__
#define __java_net_SocketPermission__

#pragma interface

#include <java/security/Permission.h>

extern "Java"
{
  namespace java
  {
    namespace net
    {
      class SocketPermission;
    }
    namespace security
    {
      class Permission;
      class PermissionCollection;
    }
  }
};

class ::java::net::SocketPermission : public ::java::security::Permission
{
public:
  SocketPermission (::java::lang::String *, ::java::lang::String *);
  jboolean equals (::java::lang::Object *);
  jint hashCode ();
  ::java::lang::String *getActions ();
  ::java::security::PermissionCollection *newPermissionCollection () { return 0; }
  jboolean implies (::java::security::Permission *);
private:
  ::java::lang::String *hostport;
  ::java::lang::String *actions;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_net_SocketPermission__ */
