// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_xml_sax_helpers_LocatorImpl__
#define __org_xml_sax_helpers_LocatorImpl__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace xml
    {
      namespace sax
      {
        namespace helpers
        {
          class LocatorImpl;
        }
        class Locator;
      }
    }
  }
};

class ::org::xml::sax::helpers::LocatorImpl : public ::java::lang::Object
{
public:
  LocatorImpl ();
  LocatorImpl (::org::xml::sax::Locator *);
  virtual ::java::lang::String *getPublicId () { return publicId; }
  virtual ::java::lang::String *getSystemId () { return systemId; }
  virtual jint getLineNumber () { return lineNumber; }
  virtual jint getColumnNumber () { return columnNumber; }
  virtual void setPublicId (::java::lang::String *);
  virtual void setSystemId (::java::lang::String *);
  virtual void setLineNumber (jint);
  virtual void setColumnNumber (jint);
private:
  ::java::lang::String *publicId;
  ::java::lang::String *systemId;
  jint lineNumber;
  jint columnNumber;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_xml_sax_helpers_LocatorImpl__ */
