// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_xml_sax_ContentHandler__
#define __org_xml_sax_ContentHandler__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace xml
    {
      namespace sax
      {
        class ContentHandler;
        class Attributes;
        class Locator;
      }
    }
  }
};

class ::org::xml::sax::ContentHandler : public ::java::lang::Object
{
public:
  virtual void setDocumentLocator (::org::xml::sax::Locator *) = 0;
  virtual void startDocument () = 0;
  virtual void endDocument () = 0;
  virtual void startPrefixMapping (::java::lang::String *, ::java::lang::String *) = 0;
  virtual void endPrefixMapping (::java::lang::String *) = 0;
  virtual void startElement (::java::lang::String *, ::java::lang::String *, ::java::lang::String *, ::org::xml::sax::Attributes *) = 0;
  virtual void endElement (::java::lang::String *, ::java::lang::String *, ::java::lang::String *) = 0;
  virtual void characters (jcharArray, jint, jint) = 0;
  virtual void ignorableWhitespace (jcharArray, jint, jint) = 0;
  virtual void processingInstruction (::java::lang::String *, ::java::lang::String *) = 0;
  virtual void skippedEntity (::java::lang::String *) = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __org_xml_sax_ContentHandler__ */
