// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_naming_ldap_LdapContext__
#define __javax_naming_ldap_LdapContext__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace naming
    {
      namespace ldap
      {
        class LdapContext;
        class Control;
        class ExtendedResponse;
        class ExtendedRequest;
      }
    }
  }
};

class ::javax::naming::ldap::LdapContext : public ::java::lang::Object
{
public:
  virtual ::javax::naming::ldap::ExtendedResponse *extendedOperation (::javax::naming::ldap::ExtendedRequest *) = 0;
  virtual ::javax::naming::ldap::LdapContext *newInstance (JArray< ::javax::naming::ldap::Control *> *) = 0;
  virtual void reconnect (JArray< ::javax::naming::ldap::Control *> *) = 0;
  virtual JArray< ::javax::naming::ldap::Control *> *getConnectControls () = 0;
  virtual void setRequestControls (JArray< ::javax::naming::ldap::Control *> *) = 0;
  virtual JArray< ::javax::naming::ldap::Control *> *getRequestControls () = 0;
  virtual JArray< ::javax::naming::ldap::Control *> *getResponseControls () = 0;
  static ::java::lang::String *CONTROL_FACTORIES;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __javax_naming_ldap_LdapContext__ */
