// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_net_JarURLConnection__
#define __java_net_JarURLConnection__

#pragma interface

#include <java/net/URLConnection.h>

extern "Java"
{
  namespace java
  {
    namespace net
    {
      class JarURLConnection;
      class URLConnection;
      class URL;
    }
  }
};

class ::java::net::JarURLConnection : public ::java::net::URLConnection
{
public:
  virtual ::java::net::URL *getJarFileURL () { return jarFileURL; }
  virtual ::java::lang::String *getEntryName () { return element; }
  JarURLConnection (::java::net::URL *);
  virtual void connect ();
  virtual ::java::io::InputStream *getInputStream ();
  virtual ::java::util::jar::JarEntry *getJarEntry ();
  virtual ::java::util::jar::JarFile *getJarFile () = 0;
  virtual ::java::lang::String *getHeaderField (::java::lang::String *);
  virtual ::java::lang::String *getHeaderField (jint);
  virtual ::java::lang::String *getHeaderFieldKey (jint);
private:
  ::java::lang::String *getKey (::java::lang::String *);
  ::java::lang::String *getField (::java::lang::String *);
  void getHeaders ();
  ::java::net::URL *jarFileURL;
public:  // actually protected
  ::java::net::URLConnection *jarFileURLConnection;
private:
  ::java::lang::String *element;
public: // actually package-private
  static ::java::util::Hashtable *conn_cache;
private:
  ::java::util::Hashtable *hdrHash;
  ::java::util::Vector *hdrVec;
  jboolean gotHeaders;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_net_JarURLConnection__ */
