// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_Font__
#define __java_awt_Font__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Font;
      namespace peer
      {
        class FontPeer;
      }
    }
  }
};

class ::java::awt::Font : public ::java::lang::Object
{
public:
  static ::java::awt::Font *decode (::java::lang::String *);
  static ::java::awt::Font *getFont (::java::lang::String *, ::java::awt::Font *);
  static ::java::awt::Font *getFont (::java::lang::String *);
  Font (::java::lang::String *, jint, jint);
  virtual ::java::lang::String *getName () { return name; }
  virtual jint getSize () { return size; }
  virtual jfloat getSize2D () { return pointSize; }
  virtual jboolean isPlain ();
  virtual jboolean isBold ();
  virtual jboolean isItalic ();
  virtual ::java::lang::String *getFamily () { return name; }
  virtual jint getStyle () { return style; }
  virtual ::java::awt::peer::FontPeer *getPeer ();
  virtual jint hashCode ();
  virtual jboolean equals (::java::lang::Object *);
  virtual ::java::lang::String *toString ();
  static const jint PLAIN = 0L;
  static const jint BOLD = 1L;
  static const jint ITALIC = 2L;
  static const jint ROMAN_BASELINE = 0L;
  static const jint CENTER_BASELINE = 1L;
  static const jint HANGING_BASELINE = 2L;
private:
  static const jlong serialVersionUID = -4206021311591459213LL;
public:  // actually protected
  ::java::lang::String *name;
  jint style;
  jint size;
  jfloat pointSize;
private:
  ::java::awt::peer::FontPeer *peer;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_Font__ */
