// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_color_ICC_ColorSpace__
#define __java_awt_color_ICC_ColorSpace__

#pragma interface

#include <java/awt/color/ColorSpace.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace color
      {
        class ICC_ColorSpace;
        class ICC_Profile;
      }
    }
  }
};

class ::java::awt::color::ICC_ColorSpace : public ::java::awt::color::ColorSpace
{
public:
  ICC_ColorSpace (::java::awt::color::ICC_Profile *);
  virtual ::java::awt::color::ICC_Profile *getProfile () { return profile; }
  virtual jfloatArray toRGB (jfloatArray);
  virtual jfloatArray fromRGB (jfloatArray);
  virtual jfloatArray toCIEXYZ (jfloatArray);
  virtual jfloatArray fromCIEXYZ (jfloatArray);
private:
  ::java::awt::color::ICC_Profile *profile;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_color_ICC_ColorSpace__ */
