// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_zip_InflaterInputStream__
#define __java_util_zip_InflaterInputStream__

#pragma interface

#include <java/io/FilterInputStream.h>
#include <gcj/array.h>

class ::java::util::zip::InflaterInputStream : public ::java::io::FilterInputStream
{
public:  // actually protected
  virtual void fill ();
public:
  InflaterInputStream (::java::io::InputStream *);
  InflaterInputStream (::java::io::InputStream *, ::java::util::zip::Inflater *);
  InflaterInputStream (::java::io::InputStream *, ::java::util::zip::Inflater *, jint);
  virtual jint read ();
  virtual jint read (jbyteArray, jint, jint);
  virtual void close ();
  virtual jint available ();
  virtual jlong skip (jlong);
public:  // actually protected
  jbyteArray buf;
  ::java::util::zip::Inflater *inf;
  jint len;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_util_zip_InflaterInputStream__ */
