// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_security_provider_SHA__
#define __gnu_java_security_provider_SHA__

#pragma interface

#include <java/security/MessageDigest.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace security
      {
        namespace provider
        {
          class SHA;
        }
      }
    }
  }
};

class ::gnu::java::security::provider::SHA : public ::java::security::MessageDigest
{
public:
  SHA ();
  virtual jint engineGetDigestLength ();
  virtual void engineUpdate (jbyte);
  virtual void engineUpdate (jbyteArray, jint, jint);
  virtual void engineReset ();
  virtual jbyteArray engineDigest ();
private:
  void munch ();
public:
  virtual ::java::lang::Object *clone ();
private:
  SHA (::gnu::java::security::provider::SHA *);
  jintArray W;
  jlong bytecount;
  jint H0;
  jint H1;
  jint H2;
  jint H3;
  jint H4;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_security_provider_SHA__ */
