// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_xml_sax_SAXNotSupportedException__
#define __org_xml_sax_SAXNotSupportedException__

#pragma interface

#include <org/xml/sax/SAXException.h>

extern "Java"
{
  namespace org
  {
    namespace xml
    {
      namespace sax
      {
        class SAXNotSupportedException;
      }
    }
  }
};

class ::org::xml::sax::SAXNotSupportedException : public ::org::xml::sax::SAXException
{
public:
  SAXNotSupportedException (::java::lang::String *);

  static ::java::lang::Class class$;
};

#endif /* __org_xml_sax_SAXNotSupportedException__ */
