// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_io_ObjectStreamField__
#define __java_io_ObjectStreamField__

#pragma interface

#include <java/lang/Object.h>

class ::java::io::ObjectStreamField : public ::java::lang::Object
{
public:
  ObjectStreamField (::java::lang::String *, ::java::lang::Class *);
  virtual ::java::lang::String *getName () { return name; }
  virtual ::java::lang::Class *getType () { return type; }
  virtual jchar getTypeCode ();
  virtual ::java::lang::String *getTypeString ();
  virtual jint getOffset () { return offset; }
public:  // actually protected
  virtual void setOffset (jint);
public:
  virtual jboolean isPrimitive ();
  virtual jint compareTo (::java::lang::Object *);
  virtual ::java::lang::String *toString ();
private:
  ::java::lang::String *name;
  ::java::lang::Class *type;
  jint offset;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_io_ObjectStreamField__ */
