// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_ComponentOrientation__
#define __java_awt_ComponentOrientation__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class ComponentOrientation;
    }
  }
};

class ::java::awt::ComponentOrientation : public ::java::lang::Object
{
public: // actually package-private
  ComponentOrientation (jint);
public:
  jboolean isHorizontal ();
  jboolean isLeftToRight ();
  static ::java::awt::ComponentOrientation *getOrientation (::java::util::Locale *);
  static ::java::awt::ComponentOrientation *getOrientation (::java::util::ResourceBundle *);
private:
  static jint HORIZONTAL_ID;
  static jint LEFT_TO_RIGHT_ID;
public:
  static ::java::awt::ComponentOrientation *LEFT_TO_RIGHT;
  static ::java::awt::ComponentOrientation *RIGHT_TO_LEFT;
  static ::java::awt::ComponentOrientation *UNKNOWN;
public: // actually package-private
  jint orientation;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_ComponentOrientation__ */
