// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_transaction_TransactionRequiredException__
#define __javax_transaction_TransactionRequiredException__

#pragma interface

#include <java/rmi/RemoteException.h>

extern "Java"
{
  namespace javax
  {
    namespace transaction
    {
      class TransactionRequiredException;
    }
  }
};

class ::javax::transaction::TransactionRequiredException : public ::java::rmi::RemoteException
{
public:
  TransactionRequiredException ();
  TransactionRequiredException (::java::lang::String *);

  static ::java::lang::Class class$;
};

#endif /* __javax_transaction_TransactionRequiredException__ */
