// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_AbstractMethodError__
#define __java_lang_AbstractMethodError__

#pragma interface

#include <java/lang/IncompatibleClassChangeError.h>

class ::java::lang::AbstractMethodError : public ::java::lang::IncompatibleClassChangeError
{
public:
  AbstractMethodError ();
  AbstractMethodError (::java::lang::String *);
public: // actually package-private
  static const jlong serialVersionUID = -1654391082989018462LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_AbstractMethodError__ */
