// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_Color__
#define __java_awt_Color__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Color;
    }
  }
};

class ::java::awt::Color : public ::java::lang::Object
{
public:
  static ::java::awt::Color *decode (::java::lang::String *);
  static ::java::awt::Color *getColor (::java::lang::String *);
  static ::java::awt::Color *getColor (::java::lang::String *, jint);
  static ::java::awt::Color *getColor (::java::lang::String *, ::java::awt::Color *);
  static jint HSBtoRGB (jfloat, jfloat, jfloat);
  static jfloatArray RGBtoHSB (jint, jint, jint, jfloatArray);
  static ::java::awt::Color *getHSBColor (jfloat, jfloat, jfloat);
  Color (jint, jint, jint);
  Color (jint, jint, jint, jint);
  Color (jint);
  Color (jint, jboolean);
  Color (jfloat, jfloat, jfloat);
  virtual jint getRed ();
  virtual jint getGreen ();
  virtual jint getBlue ();
  virtual jint getAlpha ();
  virtual jint getTransparency ();
  virtual jint getRGB () { return value; }
  virtual ::java::awt::Color *brighter ();
  virtual ::java::awt::Color *darker ();
  virtual jint hashCode () { return value; }
  virtual jboolean equals (::java::lang::Object *);
  virtual ::java::lang::String *toString ();
  static ::java::awt::Color *white;
  static ::java::awt::Color *lightGray;
  static ::java::awt::Color *gray;
  static ::java::awt::Color *darkGray;
  static ::java::awt::Color *black;
  static ::java::awt::Color *red;
  static ::java::awt::Color *pink;
  static ::java::awt::Color *orange;
  static ::java::awt::Color *yellow;
  static ::java::awt::Color *green;
  static ::java::awt::Color *magenta;
  static ::java::awt::Color *cyan;
  static ::java::awt::Color *blue;
private:
  static const jlong serialVersionUID = 118526816881161077LL;
  static const jint redmask = 16711680L;
  static const jint greenmask = 65280L;
  static const jint bluemask = 255L;
  static const jint alphamask = -16777216L;
  static const jint BRIGHT_STEP = 48L;
  jint value;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_Color__ */
