// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_io_CharConversionException__
#define __java_io_CharConversionException__

#pragma interface

#include <java/io/IOException.h>

class ::java::io::CharConversionException : public ::java::io::IOException
{
public:
  CharConversionException ();
  CharConversionException (::java::lang::String *);

  static ::java::lang::Class class$;
};

#endif /* __java_io_CharConversionException__ */
