// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_transaction_NotSupportedException__
#define __javax_transaction_NotSupportedException__

#pragma interface

#include <java/lang/Exception.h>

extern "Java"
{
  namespace javax
  {
    namespace transaction
    {
      class NotSupportedException;
    }
  }
};

class ::javax::transaction::NotSupportedException : public ::java::lang::Exception
{
public:
  NotSupportedException ();
  NotSupportedException (::java::lang::String *);

  static ::java::lang::Class class$;
};

#endif /* __javax_transaction_NotSupportedException__ */
