// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_color_ICC_Profile__
#define __java_awt_color_ICC_Profile__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace color
      {
        class ICC_Profile;
      }
    }
  }
};

class ::java::awt::color::ICC_Profile : public ::java::lang::Object
{
public: // actually package-private
  ICC_Profile (jlong);
public:
  virtual jint getNumComponents ();
public: // actually package-private
  jlong profileID;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_color_ICC_Profile__ */
