// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_geom_IllegalPathStateException__
#define __java_awt_geom_IllegalPathStateException__

#pragma interface

#include <java/lang/RuntimeException.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace geom
      {
        class IllegalPathStateException;
      }
    }
  }
};

class ::java::awt::geom::IllegalPathStateException : public ::java::lang::RuntimeException
{
public:
  IllegalPathStateException ();
  IllegalPathStateException (::java::lang::String *);

  static ::java::lang::Class class$;
};

#endif /* __java_awt_geom_IllegalPathStateException__ */
