// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_naming_spi_Resolver__
#define __javax_naming_spi_Resolver__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace naming
    {
      namespace spi
      {
        class Resolver;
        class ResolveResult;
      }
      class Name;
    }
  }
};

class ::javax::naming::spi::Resolver : public ::java::lang::Object
{
public:
  virtual ::javax::naming::spi::ResolveResult *resolveToClass (::javax::naming::Name *, ::java::lang::Class *) = 0;
  virtual ::javax::naming::spi::ResolveResult *resolveToClass (::java::lang::String *, ::java::lang::Class *) = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __javax_naming_spi_Resolver__ */
