// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_w3c_dom_traversal_NodeFilter__
#define __org_w3c_dom_traversal_NodeFilter__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace w3c
    {
      namespace dom
      {
        namespace traversal
        {
          class NodeFilter;
        }
        class Node;
      }
    }
  }
};

class ::org::w3c::dom::traversal::NodeFilter : public ::java::lang::Object
{
public:
  virtual jshort acceptNode (::org::w3c::dom::Node *) = 0;
  static const jint FILTER_ACCEPT = 1L;
  static const jint FILTER_REJECT = 2L;
  static const jint FILTER_SKIP = 3L;
  static const jint SHOW_ALL = -1L;
  static const jint SHOW_ELEMENT = 1L;
  static const jint SHOW_ATTRIBUTE = 2L;
  static const jint SHOW_TEXT = 4L;
  static const jint SHOW_CDATA_SECTION = 8L;
  static const jint SHOW_ENTITY_REFERENCE = 16L;
  static const jint SHOW_ENTITY = 32L;
  static const jint SHOW_PROCESSING_INSTRUCTION = 64L;
  static const jint SHOW_COMMENT = 128L;
  static const jint SHOW_DOCUMENT = 256L;
  static const jint SHOW_DOCUMENT_TYPE = 512L;
  static const jint SHOW_DOCUMENT_FRAGMENT = 1024L;
  static const jint SHOW_NOTATION = 2048L;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __org_w3c_dom_traversal_NodeFilter__ */
