// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_xml_sax_helpers_XMLReaderAdapter__
#define __org_xml_sax_helpers_XMLReaderAdapter__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace xml
    {
      namespace sax
      {
        class Attributes;
        class Locator;
        class InputSource;
        class ErrorHandler;
        class DTDHandler;
        class EntityResolver;
        namespace helpers
        {
          class XMLReaderAdapter;
          class XMLReaderAdapter$AttributesAdapter;
        }
        class DocumentHandler;
        class XMLReader;
      }
    }
  }
};

class ::org::xml::sax::helpers::XMLReaderAdapter : public ::java::lang::Object
{
public:
  XMLReaderAdapter ();
  XMLReaderAdapter (::org::xml::sax::XMLReader *);
private:
  void setup (::org::xml::sax::XMLReader *);
public:
  virtual void setLocale (::java::util::Locale *);
  virtual void setEntityResolver (::org::xml::sax::EntityResolver *);
  virtual void setDTDHandler (::org::xml::sax::DTDHandler *);
  virtual void setDocumentHandler (::org::xml::sax::DocumentHandler *);
  virtual void setErrorHandler (::org::xml::sax::ErrorHandler *);
  virtual void parse (::java::lang::String *);
  virtual void parse (::org::xml::sax::InputSource *);
private:
  void setupXMLReader ();
public:
  virtual void setDocumentLocator (::org::xml::sax::Locator *);
  virtual void startDocument ();
  virtual void endDocument ();
  virtual void startPrefixMapping (::java::lang::String *, ::java::lang::String *) { }
  virtual void endPrefixMapping (::java::lang::String *) { }
  virtual void startElement (::java::lang::String *, ::java::lang::String *, ::java::lang::String *, ::org::xml::sax::Attributes *);
  virtual void endElement (::java::lang::String *, ::java::lang::String *, ::java::lang::String *);
  virtual void characters (jcharArray, jint, jint);
  virtual void ignorableWhitespace (jcharArray, jint, jint);
  virtual void processingInstruction (::java::lang::String *, ::java::lang::String *);
  virtual void skippedEntity (::java::lang::String *) { }
public: // actually package-private
  ::org::xml::sax::XMLReader *xmlReader;
  ::org::xml::sax::DocumentHandler *documentHandler;
  ::org::xml::sax::helpers::XMLReaderAdapter$AttributesAdapter *qAtts;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_xml_sax_helpers_XMLReaderAdapter__ */
