// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_VMClassLoader__
#define __java_lang_VMClassLoader__

#pragma interface

#include <java/lang/Object.h>

class ::java::lang::VMClassLoader : public ::java::lang::Object
{
public: // actually package-private
  static ::java::lang::Class *getPrimitiveClass (jchar);
  VMClassLoader ();
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_VMClassLoader__ */
