// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_jar_JarException__
#define __java_util_jar_JarException__

#pragma interface

#include <java/util/zip/ZipException.h>

class ::java::util::jar::JarException : public ::java::util::zip::ZipException
{
public:
  JarException ();
  JarException (::java::lang::String *);

  static ::java::lang::Class class$;
};

#endif /* __java_util_jar_JarException__ */
