// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_net_URLClassLoader__
#define __java_net_URLClassLoader__

#pragma interface

#include <java/lang/ClassLoader.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace net
    {
      class URLClassLoader;
      class URL;
      class URLStreamHandler;
      class URLStreamHandlerFactory;
    }
  }
};

class ::java::net::URLClassLoader : public ::java::lang::ClassLoader
{
private:
  ::java::net::URLStreamHandler *getHandler0 (::java::lang::String *);
public:
  URLClassLoader (JArray< ::java::net::URL *> *);
  URLClassLoader (JArray< ::java::net::URL *> *, ::java::lang::ClassLoader *);
private:
  ::java::net::URL *jarFileize (::java::net::URL *);
public:  // actually protected
  virtual void addURL (::java::net::URL *);
public:
  URLClassLoader (JArray< ::java::net::URL *> *, ::java::lang::ClassLoader *, ::java::net::URLStreamHandlerFactory *);
  virtual JArray< ::java::net::URL *> *getURLs ();
  virtual ::java::util::Enumeration *findResources (::java::lang::String *);
  virtual ::java::net::URL *findResource (::java::lang::String *);
public:  // actually protected
  virtual ::java::lang::Class *findClass (::java::lang::String *);
public: // actually package-private
  ::java::net::URLStreamHandlerFactory *factory;
private:
  ::java::util::Vector *path;
  ::java::util::Vector *info;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_net_URLClassLoader__ */
