// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_net_DatagramSocket__
#define __java_net_DatagramSocket__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace net
    {
      class DatagramSocket;
      class DatagramPacket;
      class InetAddress;
      class DatagramSocketImpl;
    }
  }
};

class ::java::net::DatagramSocket : public ::java::lang::Object
{
public:
  DatagramSocket ();
  DatagramSocket (jint);
  DatagramSocket (jint, ::java::net::InetAddress *);
  virtual void close ();
  virtual ::java::net::InetAddress *getLocalAddress ();
  virtual jint getLocalPort ();
  virtual jint getSoTimeout ();
  virtual void receive (::java::net::DatagramPacket *);
  virtual void send (::java::net::DatagramPacket *);
  virtual void setSoTimeout (jint);
  virtual jint getReceiveBufferSize ();
  virtual jint getSendBufferSize ();
  virtual void setReceiveBufferSize (jint);
  virtual void setSendBufferSize (jint);
public: // actually package-private
  ::java::net::DatagramSocketImpl *impl;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_net_DatagramSocket__ */
