// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_w3c_dom_traversal_DocumentTraversal__
#define __org_w3c_dom_traversal_DocumentTraversal__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace w3c
    {
      namespace dom
      {
        namespace traversal
        {
          class DocumentTraversal;
          class TreeWalker;
          class NodeIterator;
          class NodeFilter;
        }
        class Node;
      }
    }
  }
};

class ::org::w3c::dom::traversal::DocumentTraversal : public ::java::lang::Object
{
public:
  virtual ::org::w3c::dom::traversal::NodeIterator *createNodeIterator (::org::w3c::dom::Node *, jint, ::org::w3c::dom::traversal::NodeFilter *, jboolean) = 0;
  virtual ::org::w3c::dom::traversal::TreeWalker *createTreeWalker (::org::w3c::dom::Node *, jint, ::org::w3c::dom::traversal::NodeFilter *, jboolean) = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __org_w3c_dom_traversal_DocumentTraversal__ */
