// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_Throwable__
#define __java_lang_Throwable__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

class ::java::lang::Throwable : public ::java::lang::Object
{
public:
  virtual ::java::lang::Throwable *fillInStackTrace ();
  virtual ::java::lang::String *getLocalizedMessage ();
  virtual ::java::lang::String *getMessage () { return detailMessage; }
  virtual void printStackTrace ();
  virtual void printStackTrace (::java::io::PrintStream *);
  virtual void printStackTrace (::java::io::PrintWriter *);
  Throwable ();
  Throwable (::java::lang::String *);
  virtual ::java::lang::String *toString ();
private:
  void printRawStackTrace (::java::io::PrintWriter *);
  ::java::lang::String *detailMessage;
public: // actually package-private
  static jboolean trace_enabled;
private:
  jbyteArray stackTrace;
  static const jlong serialVersionUID = -3042686055658047285LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_Throwable__ */
