// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_w3c_dom_DocumentType__
#define __org_w3c_dom_DocumentType__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace w3c
    {
      namespace dom
      {
        class DocumentType;
        class NamedNodeMap;
      }
    }
  }
};

class ::org::w3c::dom::DocumentType : public ::java::lang::Object
{
public:
  virtual ::java::lang::String *getName () = 0;
  virtual ::org::w3c::dom::NamedNodeMap *getEntities () = 0;
  virtual ::org::w3c::dom::NamedNodeMap *getNotations () = 0;
  virtual ::java::lang::String *getPublicId () = 0;
  virtual ::java::lang::String *getSystemId () = 0;
  virtual ::java::lang::String *getInternalSubset () = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __org_w3c_dom_DocumentType__ */
