// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_zip_ZipFile__
#define __java_util_zip_ZipFile__

#pragma interface

#include <java/lang/Object.h>

class ::java::util::zip::ZipFile : public ::java::lang::Object
{
public:
  ZipFile (::java::lang::String *);
  ZipFile (::java::io::File *);
  ZipFile (::java::io::File *, jint);
public: // actually package-private
  virtual void readDirectory ();
public:
  virtual ::java::util::Enumeration *entries ();
  virtual void close ();
  virtual ::java::util::zip::ZipEntry *getEntry (::java::lang::String *);
  virtual ::java::io::InputStream *getInputStream (::java::util::zip::ZipEntry *);
  virtual ::java::lang::String *getName () { return name; }
  virtual jint size ();
public:  // actually protected
  virtual void finalize ();
private:
  jint readu2 ();
  jint read4 ();
public:
  static const jint OPEN_READ = 1L;
  static const jint OPEN_DELETE = 4L;
public: // actually package-private
  ::java::util::zip::ZipEntry *entries__;
  jint numEntries;
  ::java::io::RandomAccessFile *file;
  ::java::lang::String *name;
  ::java::io::File *delete_on_close;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_util_zip_ZipFile__ */
