// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_security_interfaces_RSAKey__
#define __java_security_interfaces_RSAKey__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace security
    {
      namespace interfaces
      {
        class RSAKey;
      }
    }
    namespace math
    {
      class BigInteger;
    }
  }
};

class ::java::security::interfaces::RSAKey : public ::java::lang::Object
{
public:
  virtual ::java::math::BigInteger *getModulus () = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __java_security_interfaces_RSAKey__ */
