// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_event_InputEvent__
#define __java_awt_event_InputEvent__

#pragma interface

#include <java/awt/event/ComponentEvent.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace event
      {
        class InputEvent;
      }
      class Component;
    }
  }
};

class ::java::awt::event::InputEvent : public ::java::awt::event::ComponentEvent
{
public: // actually package-private
  InputEvent (::java::awt::Component *, jint);
public:
  virtual jboolean isShiftDown ();
  virtual jboolean isControlDown ();
  virtual jboolean isMetaDown ();
  virtual jboolean isAltDown ();
  virtual jboolean isAltGraphDown ();
  virtual jlong getWhen () { return when; }
  virtual jint getModifiers () { return modifiers; }
  virtual jboolean isConsumed () { return consumed; }
  virtual void consume ();
  static const jint ALT_GRAPH_MASK = 32L;
  static const jint ALT_MASK = 8L;
  static const jint BUTTON1_MASK = 16L;
  static const jint BUTTON2_MASK = 8L;
  static const jint BUTTON3_MASK = 4L;
  static const jint CTRL_MASK = 2L;
  static const jint META_MASK = 4L;
  static const jint SHIFT_MASK = 1L;
public: // actually package-private
  jlong when;
  jint modifiers;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_event_InputEvent__ */
