// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_gcj_runtime_FileDeleter__
#define __gnu_gcj_runtime_FileDeleter__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace gcj
    {
      namespace runtime
      {
        class FileDeleter;
      }
    }
  }
};

class ::gnu::gcj::runtime::FileDeleter : public ::java::lang::Object
{
public:
  static void add (::java::io::File *);
  static void deleteOnExitNow ();
  FileDeleter ();
private:
  static ::java::util::Stack *deleteOnExitStack;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_gcj_runtime_FileDeleter__ */
