// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_Panel__
#define __java_awt_Panel__

#pragma interface

#include <java/awt/Container.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Panel;
      class LayoutManager;
    }
  }
};

class ::java::awt::Panel : public ::java::awt::Container
{
public:
  Panel ();
  Panel (::java::awt::LayoutManager *);
  virtual void addNotify ();

  static ::java::lang::Class class$;
};

#endif /* __java_awt_Panel__ */
