// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_image_DataBufferByte__
#define __java_awt_image_DataBufferByte__

#pragma interface

#include <java/awt/image/DataBuffer.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace image
      {
        class DataBufferByte;
      }
    }
  }
};

class ::java::awt::image::DataBufferByte : public ::java::awt::image::DataBuffer
{
public:
  DataBufferByte (jint);
  DataBufferByte (jint, jint);
  DataBufferByte (jbyteArray, jint);
  DataBufferByte (jbyteArray, jint, jint);
  DataBufferByte (JArray<jbyteArray> *, jint);
  DataBufferByte (JArray<jbyteArray> *, jint, jintArray);
  virtual jbyteArray getData () { return data; }
  virtual jbyteArray getData (jint);
  virtual JArray<jbyteArray> * getBankData () { return bankData; }
  virtual jint getElem (jint);
  virtual jint getElem (jint, jint);
  virtual void setElem (jint, jint);
  virtual void setElem (jint, jint, jint);
private:
  jbyteArray data;
  JArray<jbyteArray> * bankData;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_image_DataBufferByte__ */
