// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_ArrayStoreException__
#define __java_lang_ArrayStoreException__

#pragma interface

#include <java/lang/RuntimeException.h>

class ::java::lang::ArrayStoreException : public ::java::lang::RuntimeException
{
public:
  ArrayStoreException ();
  ArrayStoreException (::java::lang::String *);
public: // actually package-private
  static const jlong serialVersionUID = -4522193890499838241LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_ArrayStoreException__ */
