// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_w3c_dom_Document__
#define __org_w3c_dom_Document__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace w3c
    {
      namespace dom
      {
        class Document;
        class Node;
        class NodeList;
        class EntityReference;
        class Attr;
        class ProcessingInstruction;
        class CDATASection;
        class Comment;
        class Text;
        class DocumentFragment;
        class Element;
        class DOMImplementation;
        class DocumentType;
      }
    }
  }
};

class ::org::w3c::dom::Document : public ::java::lang::Object
{
public:
  virtual ::org::w3c::dom::DocumentType *getDoctype () = 0;
  virtual ::org::w3c::dom::DOMImplementation *getImplementation () = 0;
  virtual ::org::w3c::dom::Element *getDocumentElement () = 0;
  virtual ::org::w3c::dom::Element *createElement (::java::lang::String *) = 0;
  virtual ::org::w3c::dom::DocumentFragment *createDocumentFragment () = 0;
  virtual ::org::w3c::dom::Text *createTextNode (::java::lang::String *) = 0;
  virtual ::org::w3c::dom::Comment *createComment (::java::lang::String *) = 0;
  virtual ::org::w3c::dom::CDATASection *createCDATASection (::java::lang::String *) = 0;
  virtual ::org::w3c::dom::ProcessingInstruction *createProcessingInstruction (::java::lang::String *, ::java::lang::String *) = 0;
  virtual ::org::w3c::dom::Attr *createAttribute (::java::lang::String *) = 0;
  virtual ::org::w3c::dom::EntityReference *createEntityReference (::java::lang::String *) = 0;
  virtual ::org::w3c::dom::NodeList *getElementsByTagName (::java::lang::String *) = 0;
  virtual ::org::w3c::dom::Node *importNode (::org::w3c::dom::Node *, jboolean) = 0;
  virtual ::org::w3c::dom::Element *createElementNS (::java::lang::String *, ::java::lang::String *) = 0;
  virtual ::org::w3c::dom::Attr *createAttributeNS (::java::lang::String *, ::java::lang::String *) = 0;
  virtual ::org::w3c::dom::NodeList *getElementsByTagNameNS (::java::lang::String *, ::java::lang::String *) = 0;
  virtual ::org::w3c::dom::Element *getElementById (::java::lang::String *) = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __org_w3c_dom_Document__ */
