// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_zip_ZipConstants__
#define __java_util_zip_ZipConstants__

#pragma interface

#include <java/lang/Object.h>

class ::java::util::zip::ZipConstants : public ::java::lang::Object
{
public:
  static const jint LOCAL_FILE_HEADER_SIZE = 30L;
  static const jint END_CENTRAL_DIR_SIZE = 22L;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __java_util_zip_ZipConstants__ */
