// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_beans_ParameterDescriptor__
#define __java_beans_ParameterDescriptor__

#pragma interface

#include <java/beans/FeatureDescriptor.h>

extern "Java"
{
  namespace java
  {
    namespace beans
    {
      class ParameterDescriptor;
    }
  }
};

class ::java::beans::ParameterDescriptor : public ::java::beans::FeatureDescriptor
{
public:
  ParameterDescriptor ();

  static ::java::lang::Class class$;
};

#endif /* __java_beans_ParameterDescriptor__ */
