// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_event_InputMethodEvent__
#define __java_awt_event_InputMethodEvent__

#pragma interface

#include <java/awt/AWTEvent.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace event
      {
        class InputMethodEvent;
      }
    }
  }
};

class ::java::awt::event::InputMethodEvent : public ::java::awt::AWTEvent
{
private:
  InputMethodEvent ();
public:
  static const jint CARET_POSITION_CHANGED = 1101L;
  static const jint INPUT_METHOD_FIRST = 1100L;
  static const jint INPUT_METHOD_LAST = 1101L;
  static const jint INPUT_METHOD_TEXT_CHANGED = 1100L;

  static ::java::lang::Class class$;
};

#endif /* __java_awt_event_InputMethodEvent__ */
