// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_io_NotActiveException__
#define __java_io_NotActiveException__

#pragma interface

#include <java/io/ObjectStreamException.h>

class ::java::io::NotActiveException : public ::java::io::ObjectStreamException
{
public:
  NotActiveException ();
  NotActiveException (::java::lang::String *);

  static ::java::lang::Class class$;
};

#endif /* __java_io_NotActiveException__ */
