// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_xml_sax_XMLFilter__
#define __org_xml_sax_XMLFilter__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace xml
    {
      namespace sax
      {
        class XMLFilter;
        class XMLReader;
      }
    }
  }
};

class ::org::xml::sax::XMLFilter : public ::java::lang::Object
{
public:
  virtual void setParent (::org::xml::sax::XMLReader *) = 0;
  virtual ::org::xml::sax::XMLReader *getParent () = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __org_xml_sax_XMLFilter__ */
