// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_rmi_server_SocketSecurityException__
#define __java_rmi_server_SocketSecurityException__

#pragma interface

#include <java/rmi/server/ExportException.h>

extern "Java"
{
  namespace java
  {
    namespace rmi
    {
      namespace server
      {
        class SocketSecurityException;
      }
    }
  }
};

class ::java::rmi::server::SocketSecurityException : public ::java::rmi::server::ExportException
{
public:
  SocketSecurityException (::java::lang::String *);
  SocketSecurityException (::java::lang::String *, ::java::lang::Exception *);

  static ::java::lang::Class class$;
};

#endif /* __java_rmi_server_SocketSecurityException__ */
