// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_beans_PropertyChangeSupport__
#define __java_beans_PropertyChangeSupport__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace beans
    {
      class PropertyChangeSupport;
      class PropertyChangeEvent;
      class PropertyChangeListener;
    }
  }
};

class ::java::beans::PropertyChangeSupport : public ::java::lang::Object
{
private:
  void writeObject (::java::io::ObjectOutputStream *);
  void readObject (::java::io::ObjectInputStream *);
public:
  PropertyChangeSupport (::java::lang::Object *);
  virtual void addPropertyChangeListener (::java::beans::PropertyChangeListener *);
  virtual void addPropertyChangeListener (::java::lang::String *, ::java::beans::PropertyChangeListener *);
  virtual void removePropertyChangeListener (::java::beans::PropertyChangeListener *);
  virtual void removePropertyChangeListener (::java::lang::String *, ::java::beans::PropertyChangeListener *);
  virtual void firePropertyChange (::java::beans::PropertyChangeEvent *);
  virtual void firePropertyChange (::java::lang::String *, ::java::lang::Object *, ::java::lang::Object *);
  virtual void firePropertyChange (::java::lang::String *, jboolean, jboolean);
  virtual void firePropertyChange (::java::lang::String *, jint, jint);
  virtual jboolean hasListeners (::java::lang::String *);
public: // actually package-private
  ::java::util::Hashtable *propertyListeners;
  ::java::util::Vector *listeners;
  ::java::util::Hashtable *children;
  ::java::lang::Object *source;
  jint propertyChangeSupportSerializedDataVersion;
private:
  static const jlong serialVersionUID = 6401253773779951803LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_beans_PropertyChangeSupport__ */
