// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_zip_ZipInputStream__
#define __java_util_zip_ZipInputStream__

#pragma interface

#include <java/util/zip/InflaterInputStream.h>
#include <gcj/array.h>

class ::java::util::zip::ZipInputStream : public ::java::util::zip::InflaterInputStream
{
public:
  ZipInputStream (::java::io::InputStream *);
  virtual ::java::util::zip::ZipEntry *getNextEntry ();
public:  // actually protected
  virtual void fill ();
  virtual ::java::util::zip::ZipEntry *createZipEntry (::java::lang::String *);
public:
  virtual jint read (jbyteArray, jint, jint);
  virtual jlong skip (jlong);
  virtual jint available ();
private:
  void readFully (jbyteArray);
  jint readu2 ();
  jint read4 ();
public:
  virtual void closeEntry ();
  virtual void close ();
private:
  ::java::util::zip::ZipEntry *current;
  jint current_flags;
  jint avail;
  jint compressed_bytes;
  jboolean closed;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_util_zip_ZipInputStream__ */
