// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_xml_sax_SAXException__
#define __org_xml_sax_SAXException__

#pragma interface

#include <java/lang/Exception.h>

extern "Java"
{
  namespace org
  {
    namespace xml
    {
      namespace sax
      {
        class SAXException;
      }
    }
  }
};

class ::org::xml::sax::SAXException : public ::java::lang::Exception
{
public:
  SAXException (::java::lang::String *);
  SAXException (::java::lang::Exception *);
  SAXException (::java::lang::String *, ::java::lang::Exception *);
  virtual ::java::lang::String *getMessage ();
  virtual ::java::lang::Exception *getException () { return exception; }
  virtual ::java::lang::String *toString ();
private:
  ::java::lang::Exception *exception;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_xml_sax_SAXException__ */
