// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_xml_sax_ext_LexicalHandler__
#define __org_xml_sax_ext_LexicalHandler__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace xml
    {
      namespace sax
      {
        namespace ext
        {
          class LexicalHandler;
        }
      }
    }
  }
};

class ::org::xml::sax::ext::LexicalHandler : public ::java::lang::Object
{
public:
  virtual void startDTD (::java::lang::String *, ::java::lang::String *, ::java::lang::String *) = 0;
  virtual void endDTD () = 0;
  virtual void startEntity (::java::lang::String *) = 0;
  virtual void endEntity (::java::lang::String *) = 0;
  virtual void startCDATA () = 0;
  virtual void endCDATA () = 0;
  virtual void comment (jcharArray, jint, jint) = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __org_xml_sax_ext_LexicalHandler__ */
