// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_gcj_protocol_jar_Connection__
#define __gnu_gcj_protocol_jar_Connection__

#pragma interface

#include <java/net/JarURLConnection.h>

extern "Java"
{
  namespace gnu
  {
    namespace gcj
    {
      namespace protocol
      {
        namespace jar
        {
          class Connection;
        }
      }
    }
  }
  namespace java
  {
    namespace net
    {
      class URL;
    }
  }
};

class ::gnu::gcj::protocol::jar::Connection : public ::java::net::JarURLConnection
{
public:
  Connection (::java::net::URL *);
  virtual ::java::util::jar::JarFile *getJarFile ();
public: // actually package-private
  static ::java::util::Hashtable *file_cache;
private:
  ::java::util::jar::JarFile *jarfile;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_gcj_protocol_jar_Connection__ */
