// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_gcj_runtime_FirstThread__
#define __gnu_gcj_runtime_FirstThread__

#pragma interface

#include <java/lang/Thread.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace gcj
    {
      namespace runtime
      {
        class FirstThread;
      }
    }
  }
};

class ::gnu::gcj::runtime::FirstThread : public ::java::lang::Thread
{
public:
  FirstThread (::java::lang::Class *, JArray< ::java::lang::String *> *);
  FirstThread (::java::lang::String *, JArray< ::java::lang::String *> *, jboolean);
  void run ();
private:
  ::java::lang::String *getMain (::java::lang::String *);
  void call_main ();
  ::java::lang::Class *klass;
  ::java::lang::String *klass_name;
  ::java::lang::Object *args;
  jboolean is_jar;
public: // actually package-private
  static ::java::lang::Class *Kcert;
  static ::java::lang::Class *Kfile;
  static ::java::lang::Class *Khttp;
  static ::java::lang::Class *Kjar;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_gcj_runtime_FirstThread__ */
