// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_naming_directory_NoSuchAttributeException__
#define __javax_naming_directory_NoSuchAttributeException__

#pragma interface

#include <javax/naming/NamingException.h>

extern "Java"
{
  namespace javax
  {
    namespace naming
    {
      namespace directory
      {
        class NoSuchAttributeException;
      }
    }
  }
};

class ::javax::naming::directory::NoSuchAttributeException : public ::javax::naming::NamingException
{
public:
  NoSuchAttributeException ();
  NoSuchAttributeException (::java::lang::String *);

  static ::java::lang::Class class$;
};

#endif /* __javax_naming_directory_NoSuchAttributeException__ */
