// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_w3c_dom_NamedNodeMap__
#define __org_w3c_dom_NamedNodeMap__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace w3c
    {
      namespace dom
      {
        class NamedNodeMap;
        class Node;
      }
    }
  }
};

class ::org::w3c::dom::NamedNodeMap : public ::java::lang::Object
{
public:
  virtual ::org::w3c::dom::Node *getNamedItem (::java::lang::String *) = 0;
  virtual ::org::w3c::dom::Node *setNamedItem (::org::w3c::dom::Node *) = 0;
  virtual ::org::w3c::dom::Node *removeNamedItem (::java::lang::String *) = 0;
  virtual ::org::w3c::dom::Node *item (jint) = 0;
  virtual jint getLength () = 0;
  virtual ::org::w3c::dom::Node *getNamedItemNS (::java::lang::String *, ::java::lang::String *) = 0;
  virtual ::org::w3c::dom::Node *setNamedItemNS (::org::w3c::dom::Node *) = 0;
  virtual ::org::w3c::dom::Node *removeNamedItemNS (::java::lang::String *, ::java::lang::String *) = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __org_w3c_dom_NamedNodeMap__ */
