// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_sql_CallableStatement__
#define __java_sql_CallableStatement__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace sql
    {
      class CallableStatement;
      class Array;
      class Clob;
      class Blob;
      class Ref;
      class Timestamp;
      class Time;
      class Date;
    }
    namespace math
    {
      class BigDecimal;
    }
  }
};

class ::java::sql::CallableStatement : public ::java::lang::Object
{
public:
  virtual jboolean wasNull () = 0;
  virtual ::java::lang::String *getString (jint) = 0;
  virtual ::java::lang::Object *getObject (jint) = 0;
  virtual ::java::lang::Object *getObject (jint, ::java::util::Map *) = 0;
  virtual jboolean getBoolean (jint) = 0;
  virtual jbyte getByte (jint) = 0;
  virtual jshort getShort (jint) = 0;
  virtual jint getInt (jint) = 0;
  virtual jlong getLong (jint) = 0;
  virtual jfloat getFloat (jint) = 0;
  virtual jdouble getDouble (jint) = 0;
  virtual ::java::math::BigDecimal *getBigDecimal (jint) = 0;
  virtual ::java::math::BigDecimal *getBigDecimal (jint, jint) = 0;
  virtual jbyteArray getBytes (jint) = 0;
  virtual ::java::sql::Date *getDate (jint) = 0;
  virtual ::java::sql::Date *getDate (jint, ::java::util::Calendar *) = 0;
  virtual ::java::sql::Time *getTime (jint) = 0;
  virtual ::java::sql::Time *getTime (jint, ::java::util::Calendar *) = 0;
  virtual ::java::sql::Timestamp *getTimestamp (jint) = 0;
  virtual ::java::sql::Timestamp *getTimestamp (jint, ::java::util::Calendar *) = 0;
  virtual ::java::sql::Ref *getRef (jint) = 0;
  virtual ::java::sql::Blob *getBlob (jint) = 0;
  virtual ::java::sql::Clob *getClob (jint) = 0;
  virtual ::java::sql::Array *getArray (jint) = 0;
  virtual void registerOutParameter (jint, jint) = 0;
  virtual void registerOutParameter (jint, jint, ::java::lang::String *) = 0;
  virtual void registerOutParameter (jint, jint, jint) = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __java_sql_CallableStatement__ */
