// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_io_ObjectStreamException__
#define __java_io_ObjectStreamException__

#pragma interface

#include <java/io/IOException.h>

class ::java::io::ObjectStreamException : public ::java::io::IOException
{
public:  // actually protected
  ObjectStreamException ();
  ObjectStreamException (::java::lang::String *);
public:

  static ::java::lang::Class class$;
};

#endif /* __java_io_ObjectStreamException__ */
