// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_w3c_dom_Element__
#define __org_w3c_dom_Element__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace w3c
    {
      namespace dom
      {
        class Element;
        class NodeList;
        class Attr;
      }
    }
  }
};

class ::org::w3c::dom::Element : public ::java::lang::Object
{
public:
  virtual ::java::lang::String *getTagName () = 0;
  virtual ::java::lang::String *getAttribute (::java::lang::String *) = 0;
  virtual void setAttribute (::java::lang::String *, ::java::lang::String *) = 0;
  virtual void removeAttribute (::java::lang::String *) = 0;
  virtual ::org::w3c::dom::Attr *getAttributeNode (::java::lang::String *) = 0;
  virtual ::org::w3c::dom::Attr *setAttributeNode (::org::w3c::dom::Attr *) = 0;
  virtual ::org::w3c::dom::Attr *removeAttributeNode (::org::w3c::dom::Attr *) = 0;
  virtual ::org::w3c::dom::NodeList *getElementsByTagName (::java::lang::String *) = 0;
  virtual ::java::lang::String *getAttributeNS (::java::lang::String *, ::java::lang::String *) = 0;
  virtual void setAttributeNS (::java::lang::String *, ::java::lang::String *, ::java::lang::String *) = 0;
  virtual void removeAttributeNS (::java::lang::String *, ::java::lang::String *) = 0;
  virtual ::org::w3c::dom::Attr *getAttributeNodeNS (::java::lang::String *, ::java::lang::String *) = 0;
  virtual ::org::w3c::dom::Attr *setAttributeNodeNS (::org::w3c::dom::Attr *) = 0;
  virtual ::org::w3c::dom::NodeList *getElementsByTagNameNS (::java::lang::String *, ::java::lang::String *) = 0;
  virtual jboolean hasAttribute (::java::lang::String *) = 0;
  virtual jboolean hasAttributeNS (::java::lang::String *, ::java::lang::String *) = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __org_w3c_dom_Element__ */
