// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_w3c_dom_DOMException__
#define __org_w3c_dom_DOMException__

#pragma interface

#include <java/lang/RuntimeException.h>

extern "Java"
{
  namespace org
  {
    namespace w3c
    {
      namespace dom
      {
        class DOMException;
      }
    }
  }
};

class ::org::w3c::dom::DOMException : public ::java::lang::RuntimeException
{
public:
  DOMException (jshort, ::java::lang::String *);
  jshort code;
  static const jint INDEX_SIZE_ERR = 1L;
  static const jint DOMSTRING_SIZE_ERR = 2L;
  static const jint HIERARCHY_REQUEST_ERR = 3L;
  static const jint WRONG_DOCUMENT_ERR = 4L;
  static const jint INVALID_CHARACTER_ERR = 5L;
  static const jint NO_DATA_ALLOWED_ERR = 6L;
  static const jint NO_MODIFICATION_ALLOWED_ERR = 7L;
  static const jint NOT_FOUND_ERR = 8L;
  static const jint NOT_SUPPORTED_ERR = 9L;
  static const jint INUSE_ATTRIBUTE_ERR = 10L;
  static const jint INVALID_STATE_ERR = 11L;
  static const jint SYNTAX_ERR = 12L;
  static const jint INVALID_MODIFICATION_ERR = 13L;
  static const jint NAMESPACE_ERR = 14L;
  static const jint INVALID_ACCESS_ERR = 15L;

  static ::java::lang::Class class$;
};

#endif /* __org_w3c_dom_DOMException__ */
