// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_net_MalformedURLException__
#define __java_net_MalformedURLException__

#pragma interface

#include <java/io/IOException.h>

extern "Java"
{
  namespace java
  {
    namespace net
    {
      class MalformedURLException;
    }
  }
};

class ::java::net::MalformedURLException : public ::java::io::IOException
{
public:
  MalformedURLException ();
  MalformedURLException (::java::lang::String *);

  static ::java::lang::Class class$;
};

#endif /* __java_net_MalformedURLException__ */
