// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_naming_SizeLimitExceededException__
#define __javax_naming_SizeLimitExceededException__

#pragma interface

#include <javax/naming/LimitExceededException.h>

extern "Java"
{
  namespace javax
  {
    namespace naming
    {
      class SizeLimitExceededException;
    }
  }
};

class ::javax::naming::SizeLimitExceededException : public ::javax::naming::LimitExceededException
{
public:
  SizeLimitExceededException ();
  SizeLimitExceededException (::java::lang::String *);

  static ::java::lang::Class class$;
};

#endif /* __javax_naming_SizeLimitExceededException__ */
