// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_net_InetAddress__
#define __java_net_InetAddress__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace net
    {
      class InetAddress;
    }
  }
};

class ::java::net::InetAddress : public ::java::lang::Object
{
private:
  void readObject (::java::io::ObjectInputStream *);
  void writeObject (::java::io::ObjectOutputStream *);
  static jint getFamily (jbyteArray);
public: // actually package-private
  InetAddress (jbyteArray, ::java::lang::String *);
public:
  jboolean isMulticastAddress ();
  ::java::lang::String *getHostName ();
  jbyteArray getAddress ();
private:
  static JArray< ::java::net::InetAddress *> *allocArray (jint);
  static ::java::lang::SecurityException *checkConnect (::java::lang::String *);
public:
  ::java::lang::String *getHostAddress ();
  jint hashCode ();
  jboolean equals (::java::lang::Object *);
  ::java::lang::String *toString ();
private:
  static jbyteArray aton (::java::lang::String *);
  static JArray< ::java::net::InetAddress *> *lookup (::java::lang::String *, ::java::net::InetAddress *, jboolean);
public:
  static ::java::net::InetAddress *getByName (::java::lang::String *);
  static JArray< ::java::net::InetAddress *> *getAllByName (::java::lang::String *);
private:
  static ::java::lang::String *getLocalHostname ();
public:
  static ::java::net::InetAddress *getLocalHost ();
private:
  static void getLocalHost (::java::lang::SecurityManager *);
  jint address;
public: // actually package-private
  jbyteArray addr;
  ::java::lang::String *hostName;
  jint family;
private:
  static const jlong serialVersionUID = 3286316764910316507LL;
public: // actually package-private
  static jbyteArray zeros;
  static ::java::net::InetAddress *ANY_IF;
private:
  static jbyteArray localhostAddress;
  static ::java::net::InetAddress *localhost;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_net_InetAddress__ */
