// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_net_ServerSocket__
#define __java_net_ServerSocket__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace net
    {
      class ServerSocket;
      class Socket;
      class InetAddress;
      class SocketImpl;
      class SocketImplFactory;
    }
  }
};

class ::java::net::ServerSocket : public ::java::lang::Object
{
private:
  ServerSocket ();
public:
  ServerSocket (jint);
  ServerSocket (jint, jint);
  ServerSocket (jint, jint, ::java::net::InetAddress *);
  virtual ::java::net::InetAddress *getInetAddress ();
  virtual jint getLocalPort ();
  virtual ::java::net::Socket *accept ();
public:  // actually protected
  void implAccept (::java::net::Socket *);
public:
  virtual void close ();
  virtual void setSoTimeout (jint);
  virtual jint getSoTimeout ();
  virtual ::java::lang::String *toString ();
  static void setSocketFactory (::java::net::SocketImplFactory *);
private:
  static ::java::net::SocketImplFactory *factory;
  ::java::net::SocketImpl *impl;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_net_ServerSocket__ */
