// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_xml_sax_helpers_NamespaceSupport__
#define __org_xml_sax_helpers_NamespaceSupport__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace xml
    {
      namespace sax
      {
        namespace helpers
        {
          class NamespaceSupport;
          class NamespaceSupport$Context;
        }
      }
    }
  }
};

class ::org::xml::sax::helpers::NamespaceSupport : public ::java::lang::Object
{
public:
  NamespaceSupport ();
  virtual void reset ();
  virtual void pushContext ();
  virtual void popContext ();
  virtual jboolean declarePrefix (::java::lang::String *, ::java::lang::String *);
  virtual JArray< ::java::lang::String *> *processName (::java::lang::String *, JArray< ::java::lang::String *> *, jboolean);
  virtual ::java::lang::String *getURI (::java::lang::String *);
  virtual ::java::util::Enumeration *getPrefixes ();
  virtual ::java::lang::String *getPrefix (::java::lang::String *);
  virtual ::java::util::Enumeration *getPrefixes (::java::lang::String *);
  virtual ::java::util::Enumeration *getDeclaredPrefixes ();
  static ::java::lang::String *XMLNS;
private:
  static ::java::util::Enumeration *EMPTY_ENUMERATION;
  JArray< ::org::xml::sax::helpers::NamespaceSupport$Context *> *contexts;
  ::org::xml::sax::helpers::NamespaceSupport$Context *currentContext;
  jint contextPos;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_xml_sax_helpers_NamespaceSupport__ */
