// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_CharSequence__
#define __java_lang_CharSequence__

#pragma interface

#include <java/lang/Object.h>

class ::java::lang::CharSequence : public ::java::lang::Object
{
public:
  virtual jchar charAt (jint) = 0;
  virtual jint length () = 0;
  virtual ::java::lang::CharSequence *subSequence (jint, jint) = 0;
  virtual ::java::lang::String *toString () = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __java_lang_CharSequence__ */
