// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_net_PlainSocketImpl__
#define __java_net_PlainSocketImpl__

#pragma interface

#include <java/net/SocketImpl.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace net
    {
      class SocketImpl;
      class PlainSocketImpl;
      class InetAddress;
    }
  }
};

class ::java::net::PlainSocketImpl : public ::java::net::SocketImpl
{
public:
  virtual void setOption (jint, ::java::lang::Object *);
  virtual ::java::lang::Object *getOption (jint);
public:  // actually protected
  virtual void create (jboolean);
  virtual void connect (::java::lang::String *, jint);
  virtual void connect (::java::net::InetAddress *, jint);
  virtual void bind (::java::net::InetAddress *, jint);
  virtual void listen (jint);
private:
  void accept (::java::net::PlainSocketImpl *);
public:  // actually protected
  virtual void accept (::java::net::SocketImpl *);
  virtual jint available ();
  virtual void close ();
private:
  jint read ();
  jint read (jbyteArray, jint, jint);
  void write (jint);
  void write (jbyteArray, jint, jint);
public:  // actually protected
  virtual void finalize ();
  virtual ::java::io::InputStream *getInputStream ();
  virtual ::java::io::OutputStream *getOutputStream ();
public: // actually package-private
  PlainSocketImpl ();
  static const jint _Jv_TCP_NODELAY_ = 1L;
  static const jint _Jv_SO_BINDADDR_ = 15L;
  static const jint _Jv_SO_REUSEADDR_ = 4L;
  static const jint _Jv_IP_MULTICAST_IF_ = 16L;
  static const jint _Jv_SO_LINGER_ = 128L;
  static const jint _Jv_SO_TIMEOUT_ = 4102L;
  static const jint _Jv_SO_SNDBUF_ = 4097L;
  static const jint _Jv_SO_RCVBUF_ = 4098L;
  jint fnum;
  jint timeout;
  ::java::net::InetAddress *localAddress;
private:
  ::java::io::InputStream *in;
  ::java::io::OutputStream *out;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_net_PlainSocketImpl__ */
