// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_image_IndexColorModel__
#define __java_awt_image_IndexColorModel__

#pragma interface

#include <java/awt/image/ColorModel.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace image
      {
        class IndexColorModel;
        class SampleModel;
      }
    }
  }
};

class ::java::awt::image::IndexColorModel : public ::java::awt::image::ColorModel
{
public:
  IndexColorModel (jint, jint, jbyteArray, jbyteArray, jbyteArray);
  IndexColorModel (jint, jint, jbyteArray, jbyteArray, jbyteArray, jint);
  IndexColorModel (jint, jint, jbyteArray, jbyteArray, jbyteArray, jbyteArray);
  IndexColorModel (jint, jint, jbyteArray, jint, jboolean);
  IndexColorModel (jint, jint, jbyteArray, jint, jboolean, jint, jint);
  jint getMapSize () { return size; }
  jint getTransparentPixel () { return transparent; }
  void getReds (jbyteArray);
  void getGreens (jbyteArray);
  void getBlues (jbyteArray);
  void getAlphas (jbyteArray);
  void getRGBs (jintArray);
  virtual jint getRed (jint);
  virtual jint getGreen (jint);
  virtual jint getBlue (jint);
  virtual jint getAlpha (jint);
private:
  void calcRGBArrays ();
  void calcAlphaArray ();
  void calcARGBArray ();
public:
  virtual jint getRed (::java::lang::Object *);
  virtual jint getGreen (::java::lang::Object *);
  virtual jint getBlue (::java::lang::Object *);
  virtual jint getAlpha (::java::lang::Object *);
  virtual jint getRGB (::java::lang::Object *);
  virtual ::java::lang::Object *getDataElements (jint, ::java::lang::Object *);
private:
  jint getPixelValue (jint, jint, jint, jint);
public:
  virtual jintArray getComponents (jint, jintArray, jint);
  jintArray getComponents (::java::lang::Object *, jintArray, jint);
  virtual jint getDataElement (jintArray, jint);
  virtual ::java::lang::Object *getDataElements (jintArray, jint, ::java::lang::Object *);
  virtual ::java::awt::image::SampleModel *createCompatibleSampleModel (jint, jint);
private:
  jbyteArray r;
  jbyteArray g;
  jbyteArray b;
  jbyteArray a;
  jintArray argb;
  jbyteArray cmap;
  jint start;
  jint transparent;
  jint size;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_image_IndexColorModel__ */
