// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_EventObject__
#define __java_util_EventObject__

#pragma interface

#include <java/lang/Object.h>

class ::java::util::EventObject : public ::java::lang::Object
{
public:
  EventObject (::java::lang::Object *);
  virtual ::java::lang::Object *getSource () { return source; }
  virtual ::java::lang::String *toString ();
private:
  static const jlong serialVersionUID = 5516075349620653480LL;
public:  // actually protected
  ::java::lang::Object *source;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_util_EventObject__ */
